@@ -179,7 +179,7 @@ pango_font_description_get_family (const PangoFontDescription *desc)
  * Sets the style field of a #PangoFontDescription. The
  * #PangoStyle enumeration describes whether the font is slanted and
  * the manner in which it is slanted; it can be either
- * %PANGO_STYLE_NORMAL, %PANGO_STYLE_ITALIC, or %PANGO_STYLE_OBLIQUE.
+ * #PANGO_STYLE_NORMAL, #PANGO_STYLE_ITALIC, or #PANGO_STYLE_OBLIQUE.
  * Most fonts will either have a italic style or an oblique
  * style, but not both, and font matching in Pango will 
  * match italic specifications with oblique fonts and vice-versa
@@ -219,8 +219,8 @@ pango_font_description_get_style (const PangoFontDescription *desc)
  * @desc: a #PangoFontDescription
  * @variant: the variant type for the font description.
  * 
- * Sets the variant field of a font description. The %PangoVariant
- * can either by %PANGO_VARIANT_NORMAL or %PANGO_VARIANT_SMALL_CAPS.
+ * Sets the variant field of a font description. The #PangoVariant
+ * can either be %PANGO_VARIANT_NORMAL or %PANGO_VARIANT_SMALL_CAPS.
  **/
 void
 pango_font_description_set_variant (PangoFontDescription *desc,
@@ -331,7 +331,7 @@ pango_font_description_get_stretch (const PangoFontDescription *desc)
  * pango_font_description_set_size:
  * @desc: a #PangoFontDescription
  * @size: the size for the font description in pango units.
- *        (%PANGO_SCALE pango units equals one point)
+ *        There are #PANGO_SCALE Pango units in one device unit (device unit is a point, for font sizes).
  * 
  * Sets the size field of a font description.
  **/
@@ -353,10 +353,10 @@ pango_font_description_set_size (PangoFontDescription *desc,
  * See pango_font_description_get_size().
  * 
  * Return value: the size field for the font description in pango
- *   units.  (%PANGO_SCALE pango units equals one point). Returns 0 if
- *   the stretch field has not previously been set.
- *   pango_font_description_get_set_fields() to find out if the field
- *   was explicitely set or not.
+ *   units.  (There are #PANGO_SCALE pango units in one device unit &mdash;
+ *   for fonts, font points are the device unit.) Returns 0 if the stretch field has not
+ *   previously been set.  pango_font_description_get_set_fields() to
+ *   find out if the field was explicitely set or not.
  **/
 gint
 pango_font_description_get_size (const PangoFontDescription *desc)
@@ -443,6 +443,8 @@ pango_font_description_merge (PangoFontDescription       *desc,
     desc->stretch = desc_to_merge->stretch;
   if (new_mask & PANGO_FONT_MASK_SIZE)
     desc->size = desc_to_merge->size;
+
+  desc->mask |= new_mask;
 }
 
 /**
@@ -484,6 +486,8 @@ pango_font_description_merge_static (PangoFontDescription       *desc,
     desc->stretch = desc_to_merge->stretch;
   if (new_mask & PANGO_FONT_MASK_SIZE)
     desc->size = desc_to_merge->size;
+
+  desc->mask |= new_mask;
 }
 
 static gint
@@ -807,6 +811,8 @@ pango_font_description_from_string (const char *str)
                PANGO_FONT_MASK_STRETCH;
   
   desc->family_name = NULL;
+  desc->static_family = FALSE;
+  
   desc->style = PANGO_STYLE_NORMAL;
   desc->weight = PANGO_WEIGHT_NORMAL;
   desc->variant = PANGO_VARIANT_NORMAL;
@@ -1192,7 +1198,7 @@ pango_font_metrics_unref (PangoFontMetrics *metrics)
  * actual drawn ink. It is necessary to lay out the text to figure
  * where the ink will be.)
  * 
- * Return value: the ascent, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the ascent, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_ascent (PangoFontMetrics *metrics)
@@ -1212,7 +1218,7 @@ pango_font_metrics_get_ascent (PangoFontMetrics *metrics)
  * actual drawn ink. It is necessary to lay out the text to figure
  * where the ink will be.)
  * 
- * Return value: the descent, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the descent, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_descent (PangoFontMetrics *metrics)
@@ -1231,7 +1237,7 @@ pango_font_metrics_get_descent (PangoFontMetrics *metrics)
  * determining the initial size for a window. Actual characters in
  * text will be wider and narrower than this.
  * 
- * Return value: the character width, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the character width, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_approximate_char_width (PangoFontMetrics *metrics)
@@ -1252,7 +1258,7 @@ pango_font_metrics_get_approximate_char_width (PangoFontMetrics *metrics)
  * is generally somewhat more accurate than the result of
  * pango_font_metrics_get_approximate_digit_width().
  * 
- * Return value: the digit width, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the digit width, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_approximate_digit_width (PangoFontMetrics *metrics)
